%%% Tratto 01 valutazione configurazione semplice vs braking
%% Test singolo
clear all 
close all
clc

h1=100;    %[m]
g=1.62;   %[m/s^2]
T_0s=40;  %[N]
T_B=20;   %[N]
m0=15;    %[kg]
Isp=150;  %[s]

c=Isp.*9.81;
a_0s= (T_0s ./ m0) - g;
a_Bg= (T_B ./ m0) + g;


%%%% BRAKE %%%%
ts_B=@(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B=@(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B=2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B=m0.*(1-exp(-DV_B./c));


%%% STANDARD %%%
t1_S=@(h1,a_0s) ((a_0s./g)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(g)))).^0.5;

DV_S=g*t1_S(h1,a_0s);

m_prop_S=m0.*(1-exp(-DV_S./c))

%% PLOT andamenti
clear all 
close all
clc

h1=linspace(0,300,500);  %[m]  
g=1.62;   %[m/s^2]
T_0s=50;  %[N]
t_B=linspace(0,200,1000);   %[N]
m0=15;    %[kg]
Isp=150;  %[s]

c=Isp.*9.81;

[H1, TB] = meshgrid(h1,t_B);

a_0s= (T_0s ./ m0) - g;
a_Bg= (TB ./ m0) + g;


%%%% BRAKE %%%%
ts_B=@(H1,a_0s,a_Bg) ((2*H1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B=@(H1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*H1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B=2*(a_Bg - g).*(t1_B(H1,a_0s,a_Bg)-ts_B(H1,a_0s,a_Bg))+ g*t1_B(H1,a_0s,a_Bg);

m_prop_B=m0.*(1-exp(-DV_B./c));


%%% STANDARD %%%
t1_S=@(H1,a_0s) ((a_0s./g)+1).*((2*H1)./(a_0s+(((a_0s).^2)./(g)))).^0.5;

DV_S=g*t1_S(H1,a_0s);

m_prop_S=m0.*(1-exp(-DV_S./c));

figure
surf(H1, TB, m_prop_B)
xlabel('h_1 [m]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(35, 30)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

% figure
% surfc(TB, m_prop_B, H1)
% zlabel('h_1 [m]')
% xlabel('T_B [N]')
% ylabel('m_p_r_o_p [kg]')
% grid on
% title('Brake configuration 2')
% view(35, 30)
% shading interp      %gets rid of black lines in the surface plot.
% colormap(jet(50))   %See help colormap
% colorbar            %adds a colorbar that acts as a lagend for colors.

figure
contour(TB, m_prop_B, H1,[0:10:h1(end)],'ShowText','on','LabelSpacing',1500)
zlabel('h_1 [m]')
xlabel('T_B [N]')
ylabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration 2')
colorbar

%% PLOT andamenti
clear all 
close all
clc

%h1=linspace(0,300,500);  %[m]  
h1=1000;    %[m]
g=1.62;   %[m/s^2]
m0=15;    %[kg]
T_0s=linspace(m0*g+1,m0*g+150,5000);  %[N]
t_B=linspace(0,200,1000);   %[N]
Isp=150;  %[s]

c=Isp.*9.81;

[TS, TB] = meshgrid(T_0s,t_B);

a_0s= (TS ./ m0) - g;
a_Bg= (TB ./ m0) + g;


%%%% BRAKE %%%%
ts_B=@(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B=@(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B=2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B=m0.*(1-exp(-DV_B./c));


%%% STANDARD %%%
t1_S=@(h1,a_0s) ((a_0s./g)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(g)))).^0.5;

DV_S=g*t1_S(h1,a_0s);

m_prop_S=m0.*(1-exp(-DV_S./c));

figure
surfc(TS, TB, m_prop_B)
xlabel('T_0_B [N]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(38, 16)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

% figure
% contour(TB, m_prop_B, TS,[T_0s(1):5:T_0s(end)],'ShowText','on','LabelSpacing',300)
% zlabel('T_0_B [N]')
% xlabel('T_B [N]')
% ylabel('m_p_r_o_p [kg]')
% grid on
% title('Brake configuration 2')
% colorbar

%% CONFRONTI Isp = 150
clear all
close all
clc

%h1=linspace(0,300,500);  %[m]  
h1 = 100;   %[m]
g = 1.62;   %[m/s^2]
m0 = 15;    %[kg]
T_0s = linspace(m0*g+0.4,m0*g+65,800);  %[N]
T_0s_p = [50 40 30 25];
t_B = linspace(0,200,800);   %[N]
t_B_p = [60 50 40 30 20 10 5 3 1 0];
Isp = 150;  %[s]

c = Isp.*9.81;

[TS_p, TB_p] = meshgrid(T_0s_p,t_B_p);
[TS, TB] = meshgrid(T_0s,t_B);

a_0s_p = (TS_p ./ m0) - g;
a_Bg_p = (TB_p ./ m0) + g;

a_0s = (TS ./ m0) - g;
a_Bg  = (TB ./ m0) + g;


%%%% BRAKE %%%% punti
ts_B_p = @(h1,a_0s_p,a_Bg_p) ((2*h1)./(a_0s_p+(((a_0s_p).^2)./(a_Bg_p)))).^0.5;
t1_B_p = @(h1,a_0s_p,a_Bg_p) ((a_0s_p./a_Bg_p)+1).*((2*h1)./(a_0s_p+(((a_0s_p).^2)./(a_Bg_p)))).^0.5;

DV_B_p = 2*(a_Bg_p - g).*(t1_B_p(h1,a_0s_p,a_Bg_p)-ts_B_p(h1,a_0s_p,a_Bg_p))+ g*t1_B_p(h1,a_0s_p,a_Bg_p);

m_prop_B_p = m0.*(1-exp(-DV_B_p./c));


%%%% BRAKE %%%% sup.
ts_B = @(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B = @(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B = 2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B = m0.*(1-exp(-DV_B./c));


%%%% Parte con m non costante: m0=15kg, h1=100m, Isp=150s, Vmax=NO %%%%
TSm = [50 40 30 25];
TBm = [60 50 40 30 20 10 5 3 1 0];

[TSM, TBM] = meshgrid(TSm,TBm);

load('m_prop_M_Isp150_')


figure
hold on
surf(TS, TB, m_prop_B)

plot3(TS_p, TB_p, m_prop_B_p,'.','MarkerSize',10,'MarkerEdgeColor','m','MarkerFaceColor',[0.5,0.5,0.5])

plot3(TSM, TBM, m_prop_M,'.','MarkerSize',10,'MarkerEdgeColor','k','MarkerFaceColor',[0.5,0.5,0.5])

xlabel('T_0_B [N]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(38, 16)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

%% CONFRONTI Isp = 10
clear all
close all
clc

%h1=linspace(0,300,500);  %[m]  
h1 = 100;   %[m]
g = 1.62;   %[m/s^2]
m0 = 5;    %[kg]
T_0s = linspace(m0*g+0.4,m0*g+150,1000);  %[N]
t_B = linspace(0,200,1000);   %[N]
Isp = 10;  %[s]

c = Isp.*9.81;

[TS, TB] = meshgrid(T_0s,t_B);

a_0s = (TS ./ m0) - g;
a_Bg = (TB ./ m0) + g;


%%%% BRAKE %%%%
ts_B = @(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B = @(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B = 2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B = m0.*(1-exp(-DV_B./c));


%%%% Parte con m non costante: m0=15kg, h1=100m, Isp=150s, Vmax=NO %%%%
TSm = [50 40 30 20 12 8.5];
TBm = [60 50 40 30 20 10 5 3 1 0];

[TSM, TBM] = meshgrid(TSm,TBm);

% m_prop_M = zeros(length(TBm),length(TSm))
load('m_prop_M_Isp10_')


figure
hold on
surfc(TS, TB, m_prop_B)

plot3(TSM, TBM, m_prop_M,'.','MarkerSize',10,'MarkerEdgeColor','b','MarkerFaceColor',[0.5,0.5,0.5])

xlabel('T_0_B [N]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(38, 16)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

%% CONFRONTI Puntuali
clear all
close all
clc

%h1=linspace(0,300,500);  %[m]  
h1 = 100;   %[m]
g = 1.62;   %[m/s^2]
m0 = 5;    %[kg]
T_0s = linspace(m0*g+0.4,m0*g+65,800);  %[N]
T_0s_p = [50 40 30 20 12 8.5];
t_B = linspace(0,200,800);   %[N]
t_B_p = [60 50 40 30 20 10 5 3 1 0];
Isp = 10;  %[s]

c = Isp.*9.81;

[TS_p, TB_p] = meshgrid(T_0s_p,t_B_p);
[TS, TB] = meshgrid(T_0s,t_B);

a_0s_p = (TS_p ./ m0) - g;
a_Bg_p = (TB_p ./ m0) + g;

a_0s = (TS ./ m0) - g;
a_Bg  = (TB ./ m0) + g;


%%%% BRAKE %%%% punti
ts_B_p = @(h1,a_0s_p,a_Bg_p) ((2*h1)./(a_0s_p+(((a_0s_p).^2)./(a_Bg_p)))).^0.5;
t1_B_p = @(h1,a_0s_p,a_Bg_p) ((a_0s_p./a_Bg_p)+1).*((2*h1)./(a_0s_p+(((a_0s_p).^2)./(a_Bg_p)))).^0.5;

DV_B_p = 2*(a_Bg_p - g).*(t1_B_p(h1,a_0s_p,a_Bg_p)-ts_B_p(h1,a_0s_p,a_Bg_p))+ g*t1_B_p(h1,a_0s_p,a_Bg_p);

m_prop_B_p = m0.*(1-exp(-DV_B_p./c));

%%%% BRAKE %%%% sup.
ts_B = @(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B = @(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B = 2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B = m0.*(1-exp(-DV_B./c));


%%%% Parte con m non costante: m0=15kg, h1=100m, Isp=150s, Vmax=NO %%%%
TSm = [50 40 30 20 12 8.5];
TBm = [60 50 40 30 20 10 5 3 1 0];

[TSM, TBM] = meshgrid(TSm,TBm);
% m_prop_M = zeros(length(TBm),length(TSm))
load('m_prop_M_Isp10_')
%%%



figure
hold on

surfc(TS, TB, m_prop_B)

plot3(TS_p, TB_p, m_prop_B_p,'.','MarkerSize',10,'MarkerEdgeColor','m','MarkerFaceColor',[0.5,0.5,0.5])

plot3(TSM, TBM, m_prop_M,'.','MarkerSize',10,'MarkerEdgeColor','k','MarkerFaceColor',[0.5,0.5,0.5])

%ax.XDir = 'normal'; % Da usare se si usa plot3
xlabel('T_0_B [N]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(38, 16)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

%% CONFRONTI con superfici Isp=10
clear all
close all
clc

%h1=linspace(0,300,500);  %[m]  
h1 = 100;   %[m]
g = 1.62;   %[m/s^2]
m0 = 5;    %[kg]
T_0s = linspace(m0*g+0.4,m0*g+65,800);  %[N]
T_0s_p = [50 40 30 20 12 8.5];
t_B = linspace(0,200,800);   %[N]
t_B_p = [60 50 40 30 20 10 5 3 1 0];
Isp = 10;  %[s]

c = Isp.*9.81;

[TS_p, TB_p] = meshgrid(T_0s_p,t_B_p);
[TS, TB] = meshgrid(T_0s,t_B);

a_0s_p = (TS_p ./ m0) - g;
a_Bg_p = (TB_p ./ m0) + g;

a_0s = (TS ./ m0) - g;
a_Bg  = (TB ./ m0) + g;


%%%% BRAKE %%%% punti
ts_B_p = @(h1,a_0s_p,a_Bg_p) ((2*h1)./(a_0s_p+(((a_0s_p).^2)./(a_Bg_p)))).^0.5;
t1_B_p = @(h1,a_0s_p,a_Bg_p) ((a_0s_p./a_Bg_p)+1).*((2*h1)./(a_0s_p+(((a_0s_p).^2)./(a_Bg_p)))).^0.5;

DV_B_p = 2*(a_Bg_p - g).*(t1_B_p(h1,a_0s_p,a_Bg_p)-ts_B_p(h1,a_0s_p,a_Bg_p))+ g*t1_B_p(h1,a_0s_p,a_Bg_p);

m_prop_B_p = m0.*(1-exp(-DV_B_p./c));

%%%% BRAKE %%%% sup.
ts_B = @(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B = @(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B = 2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B = m0.*(1-exp(-DV_B./c));


%%%% Parte con m non costante: m0=15kg, h1=100m, Isp=150s, Vmax=NO %%%%
TSm = [50 40 30 20 12 8.5];
TBm = [60 50 40 30 20 10 5 3 1 0];

[TSM, TBM] = meshgrid(TSm,TBm);
% m_prop_M = zeros(length(TBm),length(TSm))
load('m_prop_M_Isp10_')
%%%



figure
hold on

%surf(TS, TB, m_prop_B)

surf(TSM, TBM, m_prop_M)

plot3(TS_p, TB_p, m_prop_B_p,'.','MarkerSize',10,'MarkerEdgeColor','m','MarkerFaceColor',[0.5,0.5,0.5])

plot3(TSM, TBM, m_prop_M,'.','MarkerSize',10,'MarkerEdgeColor','k','MarkerFaceColor',[0.5,0.5,0.5])

%ax.XDir = 'normal'; % Da usare se si usa solo plot3
xlabel('T_0_B [N]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(38, 16)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

