%%% Tratto 01 valutazione configurazione semplice vs braking
%% Test singolo
clear all 
close all
clc

h1=100;    %[m]
g=1.62;   %[m/s^2]
T_0s=25;  %[N]
T_B=60;   %[N]
m0=15;    %[kg]
Isp=150;  %[s]

c=Isp.*9.81;
a_0s= (T_0s ./ m0) - g;
a_Bg= (T_B ./ m0) + g;


%%%% BRAKE %%%%
ts_B=@(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B=@(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B=2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B=m0.*(1-exp(-DV_B./c));


%%% STANDARD %%%
t1_S=@(h1,a_0s) ((a_0s./g)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(g)))).^0.5;

DV_S=g*t1_S(h1,a_0s);

m_prop_S=m0.*(1-exp(-DV_S./c))

%% PLOT andamenti
clear all 
close all
clc

h1=linspace(0,300,500);  %[m]  
g=1.62;   %[m/s^2]
T_0s=50;  %[N]
t_B=linspace(0,200,1000);   %[N]
m0=15;    %[kg]
Isp=150;  %[s]

c=Isp.*9.81;

[H1, TB] = meshgrid(h1,t_B);

a_0s= (T_0s ./ m0) - g;
a_Bg= (TB ./ m0) + g;


%%%% BRAKE %%%%
ts_B=@(H1,a_0s,a_Bg) ((2*H1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B=@(H1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*H1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B=2*(a_Bg - g).*(t1_B(H1,a_0s,a_Bg)-ts_B(H1,a_0s,a_Bg))+ g*t1_B(H1,a_0s,a_Bg);

m_prop_B=m0.*(1-exp(-DV_B./c));


%%% STANDARD %%%
t1_S=@(H1,a_0s) ((a_0s./g)+1).*((2*H1)./(a_0s+(((a_0s).^2)./(g)))).^0.5;

DV_S=g*t1_S(H1,a_0s);

m_prop_S=m0.*(1-exp(-DV_S./c));

figure
surfc(H1, TB, m_prop_B)
xlabel('h_1 [m]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(35, 30)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

% figure
% surfc(TB, m_prop_B, H1)
% zlabel('h_1 [m]')
% xlabel('T_B [N]')
% ylabel('m_p_r_o_p [kg]')
% grid on
% title('Brake configuration 2')
% view(35, 30)
% shading interp      %gets rid of black lines in the surface plot.
% colormap(jet(50))   %See help colormap
% colorbar            %adds a colorbar that acts as a lagend for colors.

figure
contour(TB, m_prop_B, H1,[0:10:h1(end)],'ShowText','on','LabelSpacing',1500)
zlabel('h_1 [m]')
xlabel('T_B [N]')
ylabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration 2')
colorbar

%% PLOT andamenti
clear all 
close all
clc

%h1=linspace(0,300,500);  %[m]  
h1=1000;    %[m]
g=1.62;   %[m/s^2]
m0=15;    %[kg]
T_0s=linspace(m0*g+1,m0*g+150,5000);  %[N]
t_B=linspace(0,200,1000);   %[N]
Isp=150;  %[s]

c=Isp.*9.81;

[TS, TB] = meshgrid(T_0s,t_B);

a_0s= (TS ./ m0) - g;
a_Bg= (TB ./ m0) + g;


%%%% BRAKE %%%%
ts_B=@(h1,a_0s,a_Bg) ((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;
t1_B=@(h1,a_0s,a_Bg) ((a_0s./a_Bg)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(a_Bg)))).^0.5;

DV_B=2*(a_Bg - g).*(t1_B(h1,a_0s,a_Bg)-ts_B(h1,a_0s,a_Bg))+ g*t1_B(h1,a_0s,a_Bg);

m_prop_B=m0.*(1-exp(-DV_B./c));


%%% STANDARD %%%
t1_S=@(h1,a_0s) ((a_0s./g)+1).*((2*h1)./(a_0s+(((a_0s).^2)./(g)))).^0.5;

DV_S=g*t1_S(h1,a_0s);

m_prop_S=m0.*(1-exp(-DV_S./c));

figure
surfc(TS, TB, m_prop_B)
xlabel('T_0_B [N]')
ylabel('T_B [N]')
zlabel('m_p_r_o_p [kg]')
grid on
title('Brake configuration')
view(38, 16)
shading interp      %gets rid of black lines in the surface plot.
colormap(jet(50))   %See help colormap
colorbar            %adds a colorbar that acts as a lagend for colors.

% figure
% contour(TB, m_prop_B, TS,[T_0s(1):5:T_0s(end)],'ShowText','on','LabelSpacing',300)
% zlabel('T_0_B [N]')
% xlabel('T_B [N]')
% ylabel('m_p_r_o_p [kg]')
% grid on
% title('Brake configuration 2')
% colorbar




