%%%% INPUT %%%%
clear all
close all
clc

filename = 'T0B_TB_Vmax=1_h1=100.mat';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PARAMETERS 01H1 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tmax_vett = linspace(25,250,45);     % [N]  Tmax=T0B
TB_vett = linspace(25,250,45);    % [N] 
% Tmax_vett = 250;     % [N] 
% TB_vett = 0.5;    % [N]

[T0B,T_B] = meshgrid(Tmax_vett,TB_vett);

Vmax1 = 1;     %[m/s]

m0 = 15;       % [kg] 15
h1 = 100;      % [m] 15
c = 150*9.81;  % [m/s] 150*9.81
th1 = 0.5*1e-3;    % [s] tempo di hovering in 1. Occhio, non puoi mettere 0s !
g = 1.62;      % [m/s^2]

tol = 10^-4;  
tol2 = 10^-1;   
tol3 = 10^-4; 

DT = 1e-5;   % passo di integrazione
t_fin = 500; % [s] tempo simulazione


%%% Inizializzazione variabili 
mprop = zeros(size(T0B,1),size(T0B,2));
Vel_max = zeros(size(T0B,1),size(T0B,2));
Z_max = zeros(size(T0B,1),size(T0B,2));
Z_end = zeros(size(T0B,1),size(T0B,2));
tLim = zeros(size(T0B,1),size(T0B,2));
tS = zeros(size(T0B,1),size(T0B,2));
t1 = zeros(size(T0B,1),size(T0B,2));
parz = zeros(size(T0B,1),size(T0B,2));
indexVel_max = 0;
Tmin = 0;
indexTmin = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%% CHIAMATA DEL MODELLO %%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:size(T0B,1)
    i
    for j = 1:size(T0B,2)
        j
        Tmax = T0B(i,j);
        TB = T_B(i,j);
        
        %%% Running the Simulink model
        %open('Tratto01ConFreno.slx');             %optional
        datiSim = sim('Tratto01ConFreno.slx');
        
        %%% Extracting data 
        xSignal = datiSim.logsout.getElement('segnali');
        t       = xSignal.Values.Time;
        m       = xSignal.Values.Data(:,5);
        z       = xSignal.Values.Data(:,1);
        V       = xSignal.Values.Data(:,2);
        T       = xSignal.Values.Data(:,4);
        
        
        mprop(i,j) = m0 - m(end);
        
        [Vel_max(i,j), indexVel_max] = max(V);
        % la funzione max restituisce anche l'indice corrispondente al
        % valore massimo, se ci sono pi valori massimi restituisce l'indice
        % del primo (quindi il minor indice). Tradotto in termini pratici,
        % nel caso si vada a raggiungere la Vmax1 e la spinta si va a
        % limitare per un certo lasso di tempo, t(indexVel_max)
        % identificherebbe quell'istante in cui la spinta passa da Tmax a
        % mg.
        
        Z_max(i,j) = max(z);
        Z_end(i,j) = z(end);
        
        tLim(i,j) = t(indexVel_max); % istante di tempo in cui si raggiunge la
        % Vmax1 e quindi T -> mg, oppure, se non si fa in tempo a
        % raggiungere Vmax1 esso identifica quando T passa da Tmax a TB
        % (ovvero identifica l'inizio della fase di decelerazione).
        
        [Tmin, indexTmin] = min(T);
        tS(i,j) = t(indexTmin); %istante di tempo in cui T passa da Tmax a TB e
        % quindi identifica l'istante in cui si  conclusa la fase di acc.
        
        parz(i,j) = (tLim(i,j)/tS(i,j))*100; %ci dice, in termini percentuali, per 
        % quanto tempo si  spinto al massimo durante la fase di acc.
        
        t1(i,j) = t(end);
        
        
    end
end

save(filename,'T0B','T_B','Tmin','Vmax1','mprop','Vel_max','Z_max','Z_end','tLim','tS','parz','t1');







