%%%% INPUT %%%%
clear all
close all
clc

filename = 'Tmax_h1_m0=15.mat';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PARAMETERS 01H1 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tmax_vett = [25:2:43 45:5:150]; %linspace(60,250,10)];     % [N] 
h1_vett = [1:1:20 25:5:50 60:10:100 120:20:200 250:50:1000];    % [m/s] 
% Tmax_vett = 250;     % [N] 
% Vmax1_vett = 100;    % [m/s]

[T0S,H1] = meshgrid(Tmax_vett,h1_vett);


m0 = 15;       % [kg] 15
Vmax1 = 10000;      % [m/s] NO EFFETTO VMAX1
c = 150*9.81;  % [m/s] 150*9.81
th1 = 0.5*1e-3;    % [s] tempo di hovering in 1. Occhio, non puoi mettere 0s !
g = 1.62;      % [m/s^2]

% Per ulteriori dettagli su queste tolleranze leggere il blocco
% "Selettore_Motore"
% tol = 10^-3;    % |h1-z-V^2/(2g)|/|h1-z| <=> tol (per capire quando 
%                 % spegnere i motori)
tol2 = 10^-1;   % |h1-z|/h1 <=> tol2 (per capire se sono nei pressi di 1, 
                % tol2 pu essere relativamente grande perch  
                % l'inversione del moto che viene usato come trigger per
                % passare alla modalit di hovering
% tol3 = 5*10^-3;   % |V-Vmax1|/Vmax1 <=> tol3 (per non superare Vmax1)

DT = 1e-4;   % passo di integrazione
t_fin = 10000; % [s] tempo simulazione


%%% Inizializzazione variabili 
mprop = zeros(size(T0S,1),size(T0S,2));
Vel_max = zeros(size(T0S,1),size(T0S,2));
Vel_fin = zeros(size(T0S,1),size(T0S,2));
Z_max = zeros(size(T0S,1),size(T0S,2));
Z_end = zeros(size(T0S,1),size(T0S,2));
tLim = zeros(size(T0S,1),size(T0S,2));
tS = zeros(size(T0S,1),size(T0S,2));
t1 = zeros(size(T0S,1),size(T0S,2));
parz = zeros(size(T0S,1),size(T0S,2));
indexVel_max = 0;
T0min = 0;
indexT0min = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%% CHIAMATA DEL MODELLO %%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:size(T0S,1)
    i
    for j = 1:size(T0S,2)
        j
        Tmax = T0S(i,j);
        h1 = H1(i,j);
        
        %%% Running the Simulink model
        %open('Tratto01h1V8.slx');             %optional
        datiSim = sim('Tratto01h1V10.slx');
        
        %%% Extracting data 
        xSignal = datiSim.logsout.getElement('segnali');
        t       = xSignal.Values.Time;
        m       = xSignal.Values.Data(:,5);
        z       = xSignal.Values.Data(:,1);
        V       = xSignal.Values.Data(:,2);
        T       = xSignal.Values.Data(:,4);
        
        
        mprop(i,j) = m0 - m(end);
        
        Vel_fin(i,j) = V(end);
        [Vel_max(i,j), indexVel_max] = max(V);
        % la funzione max restituisce anche l'indice corrispondente al
        % valore massimo, se ci sono pi valori minimi restituisce l'indice
        % del primo (quindi il minor indice). Tradotto in termini pratici,
        % nel caso si vada a raggiungere la Vmax1 e la spinta si va a
        % limitare per un certo lasso di tempo, t(indexVel_max)
        % identificherebbe quell'istante in cui la spinta passa da Tmax a
        % mg.
        
        Z_max(i,j) = max(z);
        Z_end(i,j) = z(end);
        
        tLim(i,j) = t(indexVel_max); % istante di tempo in cui si raggiunge la
        % Vmax1 e quindi T -> mg, oppure, se non si fa in tempo a
        % raggiungere Vmax1 esso identifica quando T passa da Tmax a 0
        % (ovvero identifica l'inizio della fase di decelerazione).
        
        [T0min, indexT0min] = min(T);
        tS(i,j) = t(indexT0min); %istante di tempo in cui T passa da Tmax a 0 e
        % quindi identifica l'istante in cui si  conclusa la fase di acc.
        
        parz(i,j) = (tLim(i,j)/tS(i,j))*100; %ci dice, in termini percentuali, per 
        % quanto tempo si  spinto al massimo durante la fase di acc.
        
        t1(i,j) = t(end);
        
        
    end
end

save(filename,'T0S','H1','mprop','Vel_fin','Vel_max','Z_max','Z_end','tLim','tS','parz','t1');







