%%%% INPUT %%%%
clear all
close all
clc

filename = 'Tx_max_d12_NoVmax.mat';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PARAMETERS 12H2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tx_max_vett = linspace(1,250,62);     % [N] 
d12_vett = linspace(1,250,62);        % [m] 
% Tx_max_vett = 10;     % [N] 
% d12_vett = 250;       % [m] 

[TX,D12] = meshgrid(Tx_max_vett,d12_vett);




m0 = 15;         % [kg] 15
Vmax12 = 5000;       % [m/s] 50
c = 150*9.81;    % [m/s] 150*9.81
th2 = 0.5*1e-3;    % [s] tempo di hovering in 1. Occhio, non puoi mettere 0s !
g = 1.62;        % [m/s^2]

% Per ulteriori dettagli su queste tolleranze leggere il blocco
% "Selettore_Motore"
% tol = 10^-10;  % ||V+cln{(mc/Tx)-[(mc/Tx)-(d12-x)](1/c)}-cln(mc/Tx)| <=> tol  
%                 % (per capire quando invertire la Tx)
tol2 = 10^-1;   % |d12-x|/d12 <=> tol2 (per capire se sono nei pressi di 2, 
                % tol2 pu essere relativamente grande perch  
                % l'inversione del moto che viene usato come trigger per
                % passare alla modalit di hovering.
tol3 = 10^-3;   % |V-Vmax12|/Vmax12 <=> tol3 (per non superare Vmax1)


DT = 1e-3;      % passo di integrazione
t_fin = 300;     % [s] tempo simulazione


%%% Inizializzazione variabili 
mprop = zeros(size(TX,1),size(TX,2));
Vel_max = zeros(size(TX,1),size(TX,2));
X_max = zeros(size(TX,1),size(TX,2));
X_end = zeros(size(TX,1),size(TX,2));
tLim = zeros(size(TX,1),size(TX,2));
tI = zeros(size(TX,1),size(TX,2));
t2 = zeros(size(TX,1),size(TX,2));
parz = zeros(size(TX,1),size(TX,2));
indexVel_max = 0;
Tx_min = 0;
indexTx_min = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%% CHIAMATA DEL MODELLO %%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:size(TX,1)
    i
    for j = 1:size(TX,2)
        j
        Tx_max = TX(i,j);
        d12 = D12(i,j);
        
        %%% Running the Simulink model
        %open('Tratto12h2.slx');             %optional
        datiSim = sim('Tratto12h2.slx');
        
        %%% Extracting data 
        xSignal = datiSim.logsout.getElement('segnali');
        t       = xSignal.Values.Time;
        m       = xSignal.Values.Data(:,5);
        x       = xSignal.Values.Data(:,1);
        V       = xSignal.Values.Data(:,2);
        Tx      = xSignal.Values.Data(:,4);
        
        
        mprop(i,j) = m0 - m(end);
        
        [Vel_max(i,j), indexVel_max] = max(V);
        % la funzione max restituisce anche l'indice corrispondente al
        % valore massimo, se ci sono pi valori massimi restituisce l'indice
        % del primo (quindi il minor indice). Tradotto in termini pratici,
        % nel caso si vada a raggiungere la Vmax12 e la spinta Tx si va ad
        % annullare per un certo lasso di tempo, t(indexVel_max)
        % identificherebbe quell'istante in cui la spinta passa da Tx_max a
        % 0.
        
        X_max(i,j) = max(x);
        X_end(i,j) = x(end);
        
        tLim(i,j) = t(indexVel_max); % istante di tempo in cui si raggiunge 
        % la Vmax12 e quindi Tx -> 0, oppure, se non si fa in tempo a
        % raggiungere Vmax12 esso identifica quando Tx passa da Tx_max a 
        % -Tx_max (ovvero identifica l'inizio della fase di decelerazione).
        
        [Tx_min, indexTx_min] = min(Tx);
        tI(i,j) = t(indexTx_min); %istante di tempo in cui T passa da Tx_max 
        % a -Tx_max e quindi identifica l'istante in cui si  conclusa la 
        % fase di acc.
        
        parz(i,j) = (tLim(i,j)/tI(i,j))*100; %ci dice, in termini percentuali, per 
        % quanto tempo si  spinto al massimo durante la fase di acc.
        
        t2(i,j) = t(end);
        
        
    end
end

save(filename,'TX','D12','Vmax12','mprop','Vel_max','X_max','X_end','tLim','tI','parz','t2');







