%%%% INPUT %%%%
clear all
close all
clc

warning('off') % Nei modelli Simulink spesso non sono collegate le porte ai
% plot per renderli pi rapidi, per evitare di intasare il Command Window
% si possono disattivare.

%%% DATI GENERALI %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
m0 = 15;        % [kg] MASSA INIZIALE
c = 150*9.81;   % [m/s] Velocit efficace di scarico
g = 1.62;       % [m/s^2]
tol2 = 10^-1;   % |h1-z|/h1 <=> tol2 (per capire se sono nei pressi di 1, 
                % tol2 pu essere relativamente grande perch  
                % l'inversione del moto che viene usato come trigger per
                % passare alla modalit di hovering (SALITA). La stessa
                % cosa avviene in modo analogo per lo spostamento
                % orizzontale e per la discesa verticale.
DT = 1e-4;      % passo di integrazione
t_fin = 4000;    % [s] tempo massimo di simulazione

%%% DATI SALITA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tmax = 50;        % [N] SPINTA MASSIMA durante la SALITA
Vmax1 = 5000;     % [m/s] Vmax SALITA
h_1 = 30;          % [m] Quota punto 1 SALITA
th1 = 5;         % [s] tempo di hovering in 1. Occhio, non puoi mettere 0s !

%%% DATI SPOSTAMENTO ORIZZONTALE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T12 = 18.5;     % [N] SPINTA MASSIMA durante lo spostamento orizzontale
Vmax12 = 12.8;  % [m/s] Vmax durante lo spostamento orizzontale 
d12 = 200;      % [m] distanza tra 1 e 2
th2 = 0.5; % [s] tempo di hovering in 2. Occhio, non puoi mettere 0s !

%%% DATI DISCESA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T23 = 50;        % [N] SPINTA MASSIMA durante lo spostamento orizzontale
Vmax23 = 15;  % [m/s] Vmax durante lo spostamento orizzontale 
h3 = -130;      % [m] (va negativo) differenza di quota tra 2 e 3
th3 = 10; % [s] tempo di hovering in 3. Occhio, non puoi mettere 0s !


%%% Running the Simulink model %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% open('Tratto01h1V9.slx');                 %optional
% open('Tratto12h2_AV2.slx');               %optional
% open('Tratto23h3_V2.slx');                %optional

h1=h_1;
datiSim_Salita = sim('Tratto01h1V10.slx');

%%% Extracting data 
xSignal = datiSim_Salita.logsout.getElement('segnali');
t_Salita       = xSignal.Values.Time;
m_Salita       = xSignal.Values.Data(:,5);
z_Salita       = xSignal.Values.Data(:,1);
V_Salita       = xSignal.Values.Data(:,2);
T_Salita       = xSignal.Values.Data(:,4);

m1 = m_Salita(end);
datiSim_Orizzontale = sim('Tratto12h2_Motore_unicoV1.slx');

%%% Extracting data 
xSignal = datiSim_Orizzontale.logsout.getElement('segnali');
t_Orizzontale        = xSignal.Values.Time;
m_Orizzontale        = xSignal.Values.Data(:,5);
x_Orizzontale        = xSignal.Values.Data(:,1);
V_Orizzontale        = xSignal.Values.Data(:,2);
T_Orizzontale        = xSignal.Values.Data(:,4);

m2 = m_Orizzontale(end);
datiSim_Discesa = sim('Tratto23h3_V2.slx');

%%% Extracting data 
xSignal = datiSim_Discesa.logsout.getElement('segnali');
t_Discesa        = xSignal.Values.Time;
m_Discesa        = xSignal.Values.Data(:,5);
z_Discesa        = xSignal.Values.Data(:,1);
V_Discesa        = xSignal.Values.Data(:,2);
T_Discesa        = xSignal.Values.Data(:,4);


m0 = m_Discesa(end);
h1=-h3;
datiSim_Salita2 = sim('Tratto01h1V10.slx');

%%% Extracting data 
xSignal = datiSim_Salita2.logsout.getElement('segnali');
t_Salita2       = xSignal.Values.Time;
m_Salita2       = xSignal.Values.Data(:,5);
z_Salita2       = xSignal.Values.Data(:,1);
V_Salita2       = xSignal.Values.Data(:,2);
T_Salita2       = xSignal.Values.Data(:,4);

m1 = m_Salita2(end);
datiSim_Orizzontale2 = sim('Tratto12h2_Motore_unicoV1.slx');

%%% Extracting data 
xSignal = datiSim_Orizzontale2.logsout.getElement('segnali');
t_Orizzontale2        = xSignal.Values.Time;
m_Orizzontale2        = xSignal.Values.Data(:,5);
x_Orizzontale2        = xSignal.Values.Data(:,1);
V_Orizzontale2        = xSignal.Values.Data(:,2);
T_Orizzontale2        = xSignal.Values.Data(:,4);

m2 = m_Orizzontale2(end);
h3=-h_1;
temp = th3;
th3=0.5*1e-3;
th3_2=th3;
datiSim_Discesa2 = sim('Tratto23h3_V2.slx');
th3 = temp;

%%% Extracting data 
xSignal = datiSim_Discesa2.logsout.getElement('segnali');
t_Discesa2        = xSignal.Values.Time;
m_Discesa2        = xSignal.Values.Data(:,5);
z_Discesa2        = xSignal.Values.Data(:,1);
V_Discesa2        = xSignal.Values.Data(:,2);
T_Discesa2        = xSignal.Values.Data(:,4);


% Checking everything 
subplot(1,3,1)
plot(t_Salita, z_Salita, 'g', t_Salita, m_Salita, 'm', t_Salita, V_Salita, 'b', t_Salita, T_Salita, 'r')
grid on
legend('z_S_a_l_i_t_a','m_S_a_l_i_t_a','V_S_a_l_i_t_a','T_S_a_l_i_t_a')

subplot(1,3,2)
plot(t_Orizzontale + t_Salita(end), x_Orizzontale, 	'g', t_Orizzontale + t_Salita(end), m_Orizzontale, 'm', t_Orizzontale + t_Salita(end), V_Orizzontale, 'b', t_Orizzontale + t_Salita(end), T_Orizzontale, 'r', t_Orizzontale + t_Salita(end), m_Orizzontale.*g,'k')
grid on
legend('x_O_r_i_z_z_.','m_O_r_i_z_z_.','V_O_r_i_z_z_.','T_O_r_i_z_z_.','T_V_e_r_.')

subplot(1,3,3)
plot(t_Discesa + t_Orizzontale(end), z_Discesa, 'g', t_Discesa + t_Orizzontale(end), m_Discesa, 'm', t_Discesa + t_Orizzontale(end), V_Discesa, 'b', t_Discesa + t_Orizzontale(end), T_Discesa, 'r')
grid on
legend('z_D_i_s_c_e_s_a','m_D_i_s_c_e_s_a','V_D_i_s_c_e_s_a','T_D_i_s_c_e_s_a')


figure;
hold on
% Salita
P(1) = plot(t_Salita, z_Salita, 'k');
P(2) = plot(t_Salita, m_Salita, 'Color',[0.9294 0.6941 0.1255]);
P(3) = plot(t_Salita, V_Salita, 'b');
P(4) = plot(t_Salita, T_Salita, 'r');
% Orizzontale
P(5) = plot(t_Orizzontale + t_Salita(end), x_Orizzontale,'color','#77AC30');
P(6) = plot(t_Orizzontale + t_Salita(end), V_Orizzontale,'--b');
P(7) = plot(t_Orizzontale + t_Salita(end), T_Orizzontale,'--r');
P(8) = plot(t_Orizzontale + t_Salita(end), m_Orizzontale, 'Color',[0.9294 0.6941 0.1255]);
P(9) = plot(t_Orizzontale + t_Salita(end), m_Orizzontale.*g,'r');
% Discesa
P(10) = plot(t_Discesa + t_Orizzontale(end)+t_Salita(end),z_Salita(end) + z_Discesa , 'k');
P(11) = plot(t_Discesa + t_Orizzontale(end)+t_Salita(end), m_Discesa, 'Color',[0.9294 0.6941 0.1255]);
P(12) = plot(t_Discesa + t_Orizzontale(end)+t_Salita(end), V_Discesa, 'b');
P(13) = plot(t_Discesa + t_Orizzontale(end)+t_Salita(end), T_Discesa, 'r');

t_4 = t_Discesa(end) + t_Orizzontale(end) + t_Salita(end);

% Salita2
P(14) = plot(t_Salita2 + t_4,z_Salita(end)+z_Discesa(end) + z_Salita2, 'k');
P(15) = plot(t_Salita2 + t_4, m_Salita2, 'Color',[0.9294 0.6941 0.1255]);
P(16) = plot(t_Salita2 + t_4, V_Salita2, 'b');
P(17) = plot(t_Salita2 + t_4, T_Salita2, 'r');
% Orizzontale2
P(18) = plot(t_Orizzontale2 + t_4 + t_Salita2(end),x_Orizzontale(end) - x_Orizzontale2,'color','#77AC30');
P(19) = plot(t_Orizzontale2 + t_4 + t_Salita2(end), m_Orizzontale2, 'Color',[0.9294 0.6941 0.1255]);
P(20) = plot(t_Orizzontale2 + t_4 + t_Salita2(end), V_Orizzontale2, '--b');
P(21) = plot(t_Orizzontale2 + t_4 + t_Salita2(end), T_Orizzontale2, '--r');
P(22) = plot(t_Orizzontale2 + t_4 + t_Salita2(end), m_Orizzontale2.*g,'r');
% Discesa2
P(23) = plot(t_Discesa2 + t_4 + t_Salita2(end) + t_Orizzontale2(end),z_Salita(end) + z_Discesa(end) +z_Salita2(end) + z_Discesa2, 'k');
P(24) = plot(t_Discesa2 + t_4 + t_Salita2(end) + t_Orizzontale2(end), m_Discesa2, 'Color',[0.9294 0.6941 0.1255]);
P(25) = plot(t_Discesa2 + t_4 + t_Salita2(end) + t_Orizzontale2(end), V_Discesa2, 'b');
P(26) = plot(t_Discesa2 + t_4 + t_Salita2(end) + t_Orizzontale2(end), T_Discesa2, 'r');

grid minor

%Aggiustamenti
t_END = t_Discesa2(end) + t_4 + t_Salita2(end) + t_Orizzontale2(end);

axis([-0.05*t_END (t_END+t_END*0.05) (0.1*(z_Salita(end)+z_Discesa(end))+z_Discesa(end)) (0.1*(max([d12, h_1]))+max([d12, h_1]))])

t_1 = t_Salita(end);
t_2 = t_1 + t_Orizzontale(end);
t_3 = t_2 + t_Discesa(end);
t_4 = t_3 + t_Salita2(end);
t_5 = t_4 + t_Orizzontale2(end);
t_6 = t_5 + t_Discesa2(end);
 
P(27) = plot([t_1 t_1],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);
P(28) = plot([t_2 t_2],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);
P(29) = plot([t_3 t_3],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);
P(30) = plot([t_4 t_4],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);
P(31) = plot([t_5 t_5],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);
P(32) = plot([t_6 t_6],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);
P(36) = plot([0 0],[(0.05*(max([d12, h_1]))+max([d12, h_1])) (0.05*(z_Salita(end)+z_Discesa(end))+z_Discesa(end))],'Color', [0.7 0.7 0.7]);

P(33) = plot((t_1+t_Orizzontale),(z_Salita(end).*ones(1,length(t_Orizzontale))),'k');
P(34) = plot([t_2 t_4],[x_Orizzontale(end) x_Orizzontale(end)],'color','#77AC30');
P(35) = plot((t_4+t_Orizzontale2),((z_Salita(end) + z_Discesa(end) + z_Salita2(end)).*ones(1,length(t_Orizzontale2))),'k');

legend(P([1 2 3 4 5 6 7]),'Z [m]', 'm [kg]', 'V_Z [m/s]', 'T_Z [N]','X [m]','V_X [m/s]','T_X [N]','NumColumns',2);
xlabel('time [s]')
%FINE FIGURE


disp(['Massa propellente SALITA 01 [kg]: ', num2str(m_Salita(1) - m_Salita(end-(th1/DT)))])
disp(['Massa propellente HOVERING 1 [kg]: ', num2str(m_Salita(end-(th1/DT)) - m_Salita(end))])
disp(['Massa propellente ORIZZONTALE 12 [kg]: ', num2str(m_Orizzontale(1) - m_Orizzontale(end-(th2/DT)))])
disp(['Massa propellente HOVERING 2 [kg]: ', num2str(m_Orizzontale(end-(th2/DT)) - m_Orizzontale(end))])
disp(['Massa propellente DISCESA 23 [kg]: ', num2str(m_Discesa(1) - m_Discesa(end-(th3/DT)))])
disp(['Massa propellente HOVERING 3 [kg]: ', num2str(m_Discesa(end-(th3/DT)) - m_Discesa(end))])
disp(['Massa propellente ANDATA [kg]: ', num2str(m_Salita(1) - m_Discesa(end))])
disp(['Tempo manovra ANDATA: ', num2str(t_Salita(end) + t_Orizzontale(end) + t_Discesa(end)), 's'])

fprintf('\n')

disp(['Massa propellente SALITA 45 [kg]: ', num2str(m_Salita2(1) - m_Salita2(end-(th1/DT)))])
disp(['Massa propellente HOVERING 5 [kg]: ', num2str(m_Salita2(end-(th1/DT)) - m_Salita2(end))])
disp(['Massa propellente ORIZZONTALE 56 [kg]: ', num2str(m_Orizzontale2(1) - m_Orizzontale2(end-(th2/DT)))])
disp(['Massa propellente HOVERING 6 [kg]: ', num2str(m_Orizzontale2(end-(th2/DT)) - m_Orizzontale2(end))])
disp(['Massa propellente DISCESA 67 [kg]: ', num2str(m_Discesa2(1) - m_Discesa2(end-(th3_2/DT)))])
disp(['Massa propellente HOVERING 7 [kg]: ', num2str(m_Discesa2(end-(th3_2/DT)) - m_Discesa2(end))])
disp(['Massa propellente RITORNO [kg]: ', num2str(m_Salita2(1) - m_Discesa2(end))])
disp(['Tempo manovra RITORNO: ', num2str(t_Salita2(end) + t_Orizzontale2(end) + t_Discesa2(end)), 's'])

fprintf('\n')

disp(['Massa propellente TOTALE [kg]: ', num2str(m_Salita(1) - m_Discesa2(end))])
disp(['Tempo manovra TOTALE: ', num2str(t_Salita(end) + t_Orizzontale(end) + t_Discesa(end) + t_Salita2(end) + t_Orizzontale2(end) + t_Discesa2(end)), 's'])

fprintf('\n')

disp(['Tempo manovra SALITA 01 [s]: ', num2str(t_Salita(end) - th1)])
disp(['Tempo manovra HOVERING 1 [s]: ', num2str(th1)])
disp(['Tempo manovra ORIZZONTALE 12 [s]: ', num2str(t_Orizzontale(end) - th2)])
disp(['Tempo manovra HOVERING 2 [s]: ', num2str(th2)])
disp(['Tempo manovra DISCESA 23 [s]: ', num2str(t_Discesa(end) - th3)])
disp(['Tempo manovra HOVERING 2 [s]: ', num2str(th3)])

fprintf('\n')

disp(['Tempo manovra SALITA 45 [s]: ', num2str(t_Salita2(end) - th1)])
disp(['Tempo manovra HOVERING 5 [s]: ', num2str(th1)])
disp(['Tempo manovra ORIZZONTALE 56 [s]: ', num2str(t_Orizzontale2(end) - th2)])
disp(['Tempo manovra HOVERING 6 [s]: ', num2str(th2)])
disp(['Tempo manovra DISCESA 67 [s]: ', num2str(t_Discesa2(end) - th3_2)])
disp(['Tempo manovra HOVERING 7 [s]: ', num2str(th3_2)])












