%%%% INPUT %%%%
clear all
close all
clc

warning('off') % Nei modelli Simulink spesso non sono collegate le porte ai
% plot per renderli pi rapidi, per evitare di intasare il Command Window
% si possono disattivare.

%%% DATI GENERALI %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
m0 = 15;        % [kg] MASSA INIZIALE
c = 150*9.81;   % [m/s] Velocit efficace di scarico
g = 1.62;       % [m/s^2]
tol2 = 10^-1;   % |h1-z|/h1 <=> tol2 (per capire se sono nei pressi di 1, 
                % tol2 pu essere relativamente grande perch  
                % l'inversione del moto che viene usato come trigger per
                % passare alla modalit di hovering (SALITA). La stessa
                % cosa avviene in modo analogo per lo spostamento
                % orizzontale e per la discesa verticale.
DT = 1e-4;      % passo di integrazione
t_fin = 4000;    % [s] tempo massimo di simulazione

%%% DATI SALITA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tmax = 50;      % [N] SPINTA MASSIMA durante la SALITA
Vmax1 = 5000;   % [m/s] Vmax SALITA
h1 = 30;       % [m] Quota punto 1 SALITA
th1 = 1; % [s] tempo di hovering in 1. Occhio, non puoi mettere 0s !

%%% DATI SPOSTAMENTO ORIZZONTALE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tx_max = 42;     % [N] SPINTA MASSIMA durante lo spostamento orizzontale
Vmax12 = 12;  % [m/s] Vmax durante lo spostamento orizzontale 
d12 = 150;      % [m] distanza tra 1 e 2
th2 = 1; % [s] tempo di hovering in 2. Occhio, non puoi mettere 0s !

%%% DATI DISCESA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T3 = 50;        % [N] SPINTA MASSIMA durante lo spostamento orizzontale
Vmax23 = 15;  % [m/s] Vmax durante lo spostamento orizzontale 
h3 = -150;      % [m] (va negativo) differenza di quota tra 2 e 3
th3 = 10; % [s] tempo di hovering in 3. Occhio, non puoi mettere 0s !


%%% Running the Simulink model %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% open('Tratto01h1V9.slx');                 %optional
% open('Tratto12h2_AV2.slx');               %optional
% open('Tratto23h3_V2.slx');                %optional

datiSim_Salita = sim('Tratto01h1V9.slx');

%%% Extracting data 
xSignal = datiSim_Salita.logsout.getElement('segnali');
t_Salita       = xSignal.Values.Time;
m_Salita       = xSignal.Values.Data(:,5);
z_Salita       = xSignal.Values.Data(:,1);
V_Salita       = xSignal.Values.Data(:,2);
T_Salita       = xSignal.Values.Data(:,4);

m0 = m_Salita(end);
datiSim_Orizzontale = sim('Tratto12h2_Motore_unico.slx');

%%% Extracting data 
xSignal = datiSim_Orizzontale.logsout.getElement('segnali');
t_Orizzontale        = xSignal.Values.Time;
m_Orizzontale        = xSignal.Values.Data(:,5);
x_Orizzontale        = xSignal.Values.Data(:,1);
V_Orizzontale        = xSignal.Values.Data(:,2);
T_Orizzontale        = xSignal.Values.Data(:,4);


m0 = m_Orizzontale(end);
datiSim_Discesa = sim('Tratto23h3_V2.slx');

%%% Extracting data 
xSignal = datiSim_Discesa.logsout.getElement('segnali');
t_Discesa        = xSignal.Values.Time;
m_Discesa        = xSignal.Values.Data(:,5);
z_Discesa        = xSignal.Values.Data(:,1);
V_Discesa        = xSignal.Values.Data(:,2);
T_Discesa        = xSignal.Values.Data(:,4);


% Checking everything 
subplot(1,3,1)
plot(t_Salita, z_Salita, 'g', t_Salita, m_Salita, 'm', t_Salita, V_Salita, 'b', t_Salita, T_Salita, 'r')
grid on
legend('z_S_a_l_i_t_a','m_S_a_l_i_t_a','V_S_a_l_i_t_a','T_S_a_l_i_t_a')

subplot(1,3,2)
plot(t_Orizzontale, x_Orizzontale, 	'g', t_Orizzontale, m_Orizzontale, 'm', t_Orizzontale, V_Orizzontale, 'b', t_Orizzontale, T_Orizzontale, 'r', t_Orizzontale, m_Orizzontale.*g,'k')
grid on
legend('x_O_r_i_z_z_.','m_O_r_i_z_z_.','V_O_r_i_z_z_.','T_O_r_i_z_z_.','T_V_e_r_.')

subplot(1,3,3)
plot(t_Discesa, z_Discesa, 	'g', t_Discesa, m_Discesa, 'm', t_Discesa, V_Discesa, 'b', t_Discesa, T_Discesa, 'r')
grid on
legend('z_D_i_s_c_e_s_a','m_D_i_s_c_e_s_a','V_D_i_s_c_e_s_a','T_D_i_s_c_e_s_a')

disp(['Massa propellente SALITA [kg]: ', num2str(m_Salita(1) - m_Salita(end))])
disp(['Massa propellente ORIZZONTALE [kg]: ', num2str(m_Orizzontale(1) - m_Orizzontale(end))])
disp(['Massa propellente DISCESA [kg]: ', num2str(m_Discesa(1) - m_Discesa(end))])
disp(['Massa propellente TOTALE [kg]: ', num2str(m_Salita(1) - m_Discesa(end))])
disp(['Tempo manovra: ', num2str(t_Salita(end) + t_Orizzontale(end) + t_Discesa(end)), 's'])













